============================
Pilas engine - Documentación
============================

.. only:: html

    .. image:: images/pilas-logo.png


Introducción:

.. toctree::
    :maxdepth: 1

    presentacion.rst
    instalar.rst

Recorrido básico:

.. toctree::
    :maxdepth: 1

    empezando.rst
    grupos.rst
    colisiones.rst
    fisica.rst

    imagen.rst
    sonidos.rst

    dibujado_simple_en_pantalla.rst


Recorrido modulos avanzados:

.. toctree::
    :maxdepth: 1

    dibujado_avanzado_con_superficies.rst
    tareas.rst
    interpolacion.rst
    controlando_la_pantalla.rst
    comportamientos.rst
    controles.rst
    escenas.rst
    migrar_al_gestor_de_escenas.rst
    gestor_de_escenas.rst
    demos.rst
    interfaz_de_usuario.rst
    menu.rst
    mapas_y_plataformas.rst
    dialogos.rst

    camara.rst

    motores.rst

    eventos.rst
    texto.rst
    habilidades.rst

    depurando.rst

    pilas_en_pyqt.rst


Referencia completa (API):

.. toctree::
    :maxdepth: 2

    referencia.rst
    referencia-habilidades.rst


Avanzado:

.. toctree::
    :maxdepth: 1

    desarrolladores.rst
    preguntas_avanzadas.rst

    como_funciona_pilas_por_dentro.rst
